package com.ruoyi.tcZz.service;

import java.util.List;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcZdqyml;

/**
 * 重点企业名录Service接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface ITcZdqymlService 
{
    /**
     * 查询重点企业名录
     * 
     * @param id 重点企业名录主键
     * @return 重点企业名录
     */
    public TcZdqyml selectTcZdqymlById(Long id);

    /**
     * 查询重点企业名录列表
     * 
     * @param tcZdqyml 重点企业名录
     * @return 重点企业名录集合
     */
    public List<TcZdqyml> selectTcZdqymlList(TcZdqyml tcZdqyml);

    /**
     * 新增重点企业名录
     * 
     * @param tcZdqyml 重点企业名录
     * @return 结果
     */
    public int insertTcZdqyml(TcZdqyml tcZdqyml);

    /**
     * 修改重点企业名录
     * 
     * @param tcZdqyml 重点企业名录
     * @return 结果
     */
    public int updateTcZdqyml(TcZdqyml tcZdqyml);

    /**
     * 批量删除重点企业名录
     * 
     * @param ids 需要删除的重点企业名录主键集合
     * @return 结果
     */
    public int deleteTcZdqymlByIds(Long[] ids);

    /**
     * 删除重点企业名录信息
     * 
     * @param id 重点企业名录主键
     * @return 结果
     */
    public int deleteTcZdqymlById(Long id);




    /**
     * 导入网络监测统计信息
     *
     * @return 结果
     */
    public String importUser(List<TcZdqyml> tcZdqymlList);


    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(Integer isStatus,List<String> ids);
}
