package com.ruoyi.tcZz.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcZdlyjg;
import com.ruoyi.tcZz.domain.TcZdqyml;
import com.ruoyi.tcZz.service.ITcZdqymlService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 重点企业名录Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "重点企业名录")
@RequestMapping("/tcZz/netManage/zdqyml")
public class TcZdqymlController extends BaseController {
    @Autowired
    private ITcZdqymlService tcZdqymlService;

    /**
     * 查询重点企业名录列表
     */
    @ApiOperation(value = "查询重点企业名录列表", response = TcZdqyml.class)
    @GetMapping("/list")
    public TableDataInfo list(TcZdqyml tcZdqyml) {
        startPage();
        List<TcZdqyml> list = tcZdqymlService.selectTcZdqymlList(tcZdqyml);
        return getDataTable(list);
    }

    /**
     * 导出重点企业名录列表
     */
    @ApiOperation(value = "导出重点企业名录列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZdqyml tcZdqyml) {
        List<TcZdqyml> list = tcZdqymlService.selectTcZdqymlList(tcZdqyml);
        ExcelUtil<TcZdqyml> util = new ExcelUtil<TcZdqyml>(TcZdqyml.class);
        util.exportExcel(response, list, "重点企业名录数据");
    }

    /**
     * 获取重点企业名录详细信息
     */
    @ApiOperation(value = "获取重点企业名录详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcZdqymlService.selectTcZdqymlById(id));
    }

    /**
     * 新增重点企业名录
     */
    @ApiOperation(value = "新增重点企业名录")
    @PostMapping
    public AjaxResult add(@RequestBody TcZdqyml tcZdqyml) {
        return toAjax(tcZdqymlService.insertTcZdqyml(tcZdqyml));
    }

    /**
     * 修改重点企业名录
     */
    @ApiOperation(value = "修改重点企业名录")
    @PutMapping
    public AjaxResult edit(@RequestBody TcZdqyml tcZdqyml) {
        return toAjax(tcZdqymlService.updateTcZdqyml(tcZdqyml));
    }

    /**
     * 删除重点企业名录
     */
    @ApiOperation(value = "删除重点企业名录")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcZdqymlService.deleteTcZdqymlByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcZdqyml> util = new ExcelUtil<TcZdqyml>(TcZdqyml.class);
        List<TcZdqyml> tcZdqymlList = util.importExcel(file.getInputStream());
        tcZdqymlService.importUser(tcZdqymlList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus,@RequestParam("ids") List<String> ids) {
        tcZdqymlService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcZdqyml> util = new ExcelUtil<TcZdqyml>(TcZdqyml.class);
        util.importTemplateExcel(response, " 重点企业名录");
    }
}
